@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class PMailImportData : public LibImportWizard::AbstractImporter
 {
 public:
     explicit PMailImportData(QObject *parent, const QList<QVariant> & = QList<QVariant>());
-    ~PMailImportData();
+    ~PMailImportData() override;
 
     TypeSupportedOptions supportedOption() override;
     bool foundMailer() const override;
