@@ -22,14 +22,14 @@
 #include "createtripwidget.h"
 
 #include <QVBoxLayout>
-#include <QLabel>
 #include <QPushButton>
 
 #include <kconfig.h>
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <KConfig>
-#include <KSharedConfigPtr>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 #include <AkonadiCore/Monitor>
 #include <KSharedConfig>
