@@ -62,7 +62,6 @@
 UnreadMailsInCollectionsProxy::UnreadMailsInCollectionsProxy(QObject *parent)
     : QSortFilterProxyModel(parent)
 {
-
 }
 
 bool UnreadMailsInCollectionsProxy::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
@@ -83,7 +82,7 @@ UnreadMailsInCollectionsWidget::UnreadMailsInCollectionsWidget(QWidget *parent,
     : QWidget(parent, f)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    QPushButton *configureButton = new QPushButton(QLatin1String("Configure"));
+    QPushButton *configureButton = new QPushButton(QStringLiteral("Configure"));
     connect(configureButton, SIGNAL(clicked(bool)), SLOT(configure()));
     layout->addWidget(configureButton);
 
@@ -148,7 +147,6 @@ UnreadMailsInCollectionsWidget::~UnreadMailsInCollectionsWidget()
 
 void UnreadMailsInCollectionsWidget::saveCheckState()
 {
-
     ETMViewStateSaver saver;
     saver.setSelectionModel(m_checkedItemModel);
 
