@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class MergeContactsPluginInterface : public PimCommon::GenericPluginInterface
 {
 public:
     explicit MergeContactsPluginInterface(QObject *parent = nullptr);
-    ~MergeContactsPluginInterface();
+    ~MergeContactsPluginInterface() override;
 
     void exec() override;
     void createAction(KActionCollection *ac) override;
