@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -41,7 +41,7 @@ void SearchDuplicatesPluginInterface::createAction(KActionCollection *ac)
     action->setText(i18n("Search Duplicate Contacts..."));
     connect(action, &QAction::triggered, this, &SearchDuplicatesPluginInterface::slotActivated);
     PimCommon::ActionType type(action, PimCommon::ActionType::Tools);
-    setActionType(type);
+    addActionType(type);
 }
 
 void SearchDuplicatesPluginInterface::slotActivated()
