@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@ class AutomaticAddContactsConfigureWidget : public MessageComposer::PluginEditor
     Q_OBJECT
 public:
     explicit AutomaticAddContactsConfigureWidget(QWidget *parent = nullptr);
-    ~AutomaticAddContactsConfigureWidget();
+    ~AutomaticAddContactsConfigureWidget() override;
 
     void loadSettings() override;
     void saveSettings() override;
