@@ -24,11 +24,12 @@
 
 #include <MimeTreeParser/ObjectTreeParser>
 #include <MessageViewer/CSSHelperBase>
-#include <MimeTreeParser/FileHtmlWriter>
+#include <MessageViewer/FileHtmlWriter>
 
 #include <KMime/Message>
 #include <QDir>
 #include <QIcon>
+#include <QPalette>
 #include <QProcess>
 #include <QStandardPaths>
 #include <QStyle>
@@ -53,7 +54,12 @@ Q_CONSTRUCTOR_FUNCTION(initLocale)
 void RenderTest::initTestCase()
 {
     QApplication::setStyle(QStyleFactory::create(QStringLiteral("Fusion")));
-    QApplication::setPalette(QApplication::style()->standardPalette());
+    QPalette p(QApplication::style()->standardPalette());
+    p.setCurrentColorGroup(QPalette::Normal);
+    p.setColor(QPalette::Button, QColor::fromRgb(0xef, 0xeb, 0xe7));
+    p.setColor(QPalette::ButtonText, QColor::fromRgb(0, 0, 0));
+    p.setColor(QPalette::Shadow, QColor::fromRgb(0x76, 0x74, 0x72));
+    QApplication::setPalette(p);
 }
 
 void RenderTest::testRender_data()
@@ -89,7 +95,7 @@ void RenderTest::testRender()
     msg->parse();
 
     // render the mail
-    MimeTreeParser::FileHtmlWriter fileWriter(outFileName);
+    MessageViewer::FileHtmlWriter fileWriter(outFileName);
     fileWriter.begin();
     QImage paintDevice;
     MessageViewer::CSSHelperBase cssHelper(&paintDevice);
@@ -134,7 +140,7 @@ void RenderTest::testRenderKeyDetails()
 
     // render the mail
     QEventLoop loop;
-    MimeTreeParser::FileHtmlWriter fileWriter(outFileName);
+    MessageViewer::FileHtmlWriter fileWriter(outFileName);
     fileWriter.begin();
     QImage paintDevice;
     MessageViewer::CSSHelperBase cssHelper(&paintDevice);
@@ -160,8 +166,8 @@ void RenderTest::testRenderKeyDetails()
         MimeTreeParser::ObjectTreeParser otp(&testSource, &nodeHelper);
         fileWriter.begin();
         fileWriter.write(QStringLiteral("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n"
-                                    "<html>\n"
-                                    "<body>\n"));
+                                        "<html>\n"
+                                        "<body>\n"));
         otp.parseObjectTree(msg.data());
 
         fileWriter.write(QStringLiteral("</body></html>"));
@@ -171,8 +177,6 @@ void RenderTest::testRenderKeyDetails()
     }
 }
 
-
-
 void RenderTest::compareFile(const QString &outFile, const QString &referenceFile)
 {
     QVERIFY(QFile::exists(outFile));
