@@ -4,7 +4,7 @@
   Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
   Copyright (c) 2007 Volker Krause <vkrause@kde.org>
   Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  Copyright (c) 2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@
 #include <MessageViewer/MessagePartRenderPlugin>
 #include <MessageViewer/MessageViewerSettings>
 #include <MessageViewer/Viewer>
-#include <MimeTreeParser/HtmlWriter>
+#include <MessageViewer/HtmlWriter>
 #include <MimeTreeParser/BodyPart>
 #include <MimeTreeParser/MessagePart>
 using namespace MessageViewer;
@@ -183,7 +183,7 @@ private:
 class Formatter : public MessageViewer::MessagePartRendererBase
 {
 public:
-    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *writer, MessageViewer::RenderContext *) const override
+    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MessageViewer::HtmlWriter *writer, MessageViewer::RenderContext *) const override
     {
         QMimeDatabase db;
         auto mt = db.mimeTypeForName(QString::fromLatin1(msgPart->content()->contentType()->mimeType().toLower()));
@@ -842,7 +842,7 @@ public:
                 } else {
                     queryStr = i18n("Do you really want to cancel this invitation?");
                 }
-            } else if (path.startsWith(QStringLiteral("ATTACH:"))) {
+            } else if (path.startsWith(QLatin1String("ATTACH:"))) {
                 return false;
             } else {
                 queryStr = i18n("%1?", path);
@@ -1246,7 +1246,7 @@ public:
     {
         // filter out known paths that don't belong to this type of urlmanager.
         // kolab/issue4054 msg27201
-        if (path.contains(QStringLiteral("addToAddressBook:")) || path.contains(QStringLiteral("updateToAddressBook"))) {
+        if (path.contains(QLatin1String("addToAddressBook:")) || path.contains(QLatin1String("updateToAddressBook"))) {
             return false;
         }
 
@@ -1372,7 +1372,7 @@ public:
             result = true;
         }
 
-        if (path.startsWith(QStringLiteral("ATTACH:"))) {
+        if (path.startsWith(QLatin1String("ATTACH:"))) {
             const QString name = QString::fromUtf8(QByteArray::fromBase64(path.mid(7).toUtf8()));
             result = openAttachment(name, iCal);
         }
@@ -1392,7 +1392,7 @@ public:
     bool handleContextMenuRequest(MimeTreeParser::Interface::BodyPart *part, const QString &path, const QPoint &point) const override
     {
         QString name = path;
-        if (path.startsWith(QStringLiteral("ATTACH:"))) {
+        if (path.startsWith(QLatin1String("ATTACH:"))) {
             name = QString::fromUtf8(QByteArray::fromBase64(path.mid(7).toUtf8()));
         } else {
             return false; //because it isn't an attachment inviation
@@ -1455,7 +1455,7 @@ public:
                 return i18n("Forward invitation");
             } else if (path == QLatin1String("cancel")) {
                 return i18n("Remove invitation from my calendar");
-            } else if (path.startsWith(QStringLiteral("ATTACH:"))) {
+            } else if (path.startsWith(QLatin1String("ATTACH:"))) {
                 const QString name = QString::fromUtf8(QByteArray::fromBase64(path.mid(7).toUtf8()));
                 return i18n("Open attachment \"%1\"", name);
             }
