@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,10 +22,10 @@
 #include "fancyheaderstyle.h"
 #include "messageviewer/richheaderstrategy.h"
 #include <kpluginfactory.h>
+
 using namespace MessageViewer;
 
-K_PLUGIN_FACTORY_WITH_JSON(MessageViewerFancyHeaderStylePluginFactory, "messageviewer_fancyheaderstyleplugin.json", registerPlugin<FancyHeaderStylePlugin>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(FancyHeaderStylePlugin, "messageviewer_fancyheaderstyleplugin.json")
 
 FancyHeaderStylePlugin::FancyHeaderStylePlugin(QObject *parent, const QList<QVariant> &)
     : MessageViewer::HeaderStylePlugin(parent)
