@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,10 +22,10 @@
 #include "standardheaderstrategy.h"
 #include "messageviewer/plainheaderstyle.h"
 #include <kpluginfactory.h>
+
 using namespace MessageViewer;
 
-K_PLUGIN_FACTORY_WITH_JSON(MessageViewerStandardsHeaderStylePluginFactory, "messageviewer_standardsheaderstyleplugin.json", registerPlugin<StandardsHeaderStylePlugin>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(StandardsHeaderStylePlugin, "messageviewer_standardsheaderstyleplugin.json")
 
 StandardsHeaderStylePlugin::StandardsHeaderStylePlugin(QObject *parent, const QList<QVariant> &)
     : MessageViewer::HeaderStylePlugin(parent)
