@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,8 +23,7 @@
 #include <kpluginfactory.h>
 
 using namespace MessageViewer;
-K_PLUGIN_FACTORY_WITH_JSON(ViewerPluginCreatenoteFactory, "messageviewer_createnoteplugin.json", registerPlugin<ViewerPluginCreatenote>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(ViewerPluginCreatenote, "messageviewer_createnoteplugin.json")
 
 ViewerPluginCreatenote::ViewerPluginCreatenote(QObject *parent, const QList<QVariant> &)
     : MessageViewer::ViewerPlugin(parent)
