@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ class ViewerPluginCreatenoteInterface : public ViewerPluginInterface
     Q_OBJECT
 public:
     explicit ViewerPluginCreatenoteInterface(KActionCollection *ac, QWidget *parent = nullptr);
-    ~ViewerPluginCreatenoteInterface();
+    ~ViewerPluginCreatenoteInterface() override;
 
     void setText(const QString &text) override;
     QList<QAction *> actions() const override;
