@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@ public:
     explicit TemplateParserEmailAddressRequesterAkonadi(QWidget *parent = nullptr, const QList<QVariant> & =
     {
     });
-    ~TemplateParserEmailAddressRequesterAkonadi();
+    ~TemplateParserEmailAddressRequesterAkonadi() override;
 
     QString text() const override;
     void setText(const QString &str) override;
