@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -56,7 +56,6 @@ bool AdblockInterceptorInterface::interceptRequest(QWebEngineUrlRequestInfo &inf
 QList<QAction *> AdblockInterceptorInterface::interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const
 {
     QList<QAction *> lstAction;
-    qDebug() << " mAdblockManager->isEnabled()" << mAdblockManager->isEnabled();
     if (mAdblockManager->isEnabled()) {
         lstAction.append(mShowBlockableItems);
         if (!result.imageUrl().isEmpty()) {
@@ -93,7 +92,9 @@ void AdblockInterceptorInterface::setWebEngineView(QWebEngineView *webEngineView
 
 void AdblockInterceptorInterface::slotBlockImage()
 {
+    qDebug() << " void AdblockInterceptorInterface::slotBlockImage()";
     if (mCurrentWebHitTest.imageUrl().isValid()) {
+        qDebug() << " mCurrentWebHitTest.imageUrl()"<<mCurrentWebHitTest.imageUrl();
         //TODO block it.
     }
     //TODO
@@ -101,6 +102,7 @@ void AdblockInterceptorInterface::slotBlockImage()
 
 void AdblockInterceptorInterface::slotSearchItemsDone(const QVector<AdBlock::AdBlockResult> &result)
 {
+    //TODO update
     QPointer<AdBlock::AdBlockBlockableItemsDialog> dlg = new AdBlock::AdBlockBlockableItemsDialog(mWebEngineView);
     dlg->setAdblockResult(result);
     dlg->exec();
